@@ -1,7 +1,9 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2018  Iban Cereijo.
+ * Copyright (C) 2004-2008  Jairo Chapela.
+
  *
  * This file is part of lingot.
  *
@@ -20,15 +22,22 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#ifdef OSS
+
 #ifndef __LINGOT_AUDIO_OSS_H__
 #define __LINGOT_AUDIO_OSS_H__
 
 #include "lingot-audio.h"
 
-LingotAudioHandler* lingot_audio_oss_new(char* device, int sample_rate);
+void lingot_audio_oss_new(LingotAudioHandler*, const char* device, int sample_rate);
+// In case of failure, audio_system is set to -1.
+
 void lingot_audio_oss_destroy(LingotAudioHandler*);
+
 int lingot_audio_oss_read(LingotAudioHandler*);
-LingotAudioSystemProperties* lingot_audio_oss_get_audio_system_properties(
-		audio_system_t);
+
+int lingot_audio_oss_get_audio_system_properties(LingotAudioSystemProperties*);
+// Return status : 0 for OK, else -1.
 
 #endif
+#endif
