@@ -1,7 +1,9 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2018  Iban Cereijo.
+ * Copyright (C) 2004-2008  Jairo Chapela.
+
  *
  * This file is part of lingot.
  *
@@ -31,14 +33,18 @@
 #include <jack/jack.h>
 #endif
 
+#ifdef PULSEAUDIO
+#include <pulse/simple.h>
+#endif
+
 #include "lingot-config.h"
 
 typedef void (*LingotAudioProcessCallback)(FLT* read_buffer,
-		int read_buffer_size, void *arg);
+		unsigned int read_buffer_size_samples, void *arg);
 
-typedef struct _LingotAudioHandler LingotAudioHandler;
+#define FLT_SAMPLE_SCALE	32767.0
 
-struct _LingotAudioHandler {
+typedef struct {
 
 	int audio_system;
 	char device[100];
@@ -46,27 +52,36 @@ struct _LingotAudioHandler {
 	LingotAudioProcessCallback process_callback;
 	void* process_callback_arg;
 
-#ifdef ALSA
-	snd_pcm_t *capture_handle;
-#endif
-
+#	ifdef OSS
 	int dsp; // file handler.
-	int read_buffer_size;
-	SAMPLE_TYPE* read_buffer;
-	FLT* flt_read_buffer;
-
+#	endif
+#	ifdef ALSA
+	snd_pcm_t *capture_handle;
+#	endif
 #	ifdef JACK
 	jack_port_t *jack_input_port;
 	jack_client_t *jack_client;
 	int nframes;
+#	endif
+#	ifdef PULSEAUDIO
+	pa_simple *pa_client;
+#	endif
+#	if !defined(OSS) && !defined(ALSA) && !defined(PULSEAUDIO) && !defined(JACK)
+#	error "No audio system has been enabled"
 #	endif
 
-	//	char error_message[100];
+	unsigned int read_buffer_size_samples;
+	FLT* flt_read_buffer;
+
 	unsigned int real_sample_rate;
 
+	short bytes_per_sample;
+
 	// pthread-related  member variables
 	pthread_t thread_input_read;
 	pthread_attr_t thread_input_read_attr;
+	pthread_cond_t thread_input_read_cond;
+	pthread_mutex_t thread_input_read_mutex;
 
 	// indicates whether the audio thread is running
 	int running;
@@ -74,31 +89,32 @@ struct _LingotAudioHandler {
 	// indicates whether the thread was interrupted (by the audio server, not
 	// by the user)
 	int interrupted;
-};
+} LingotAudioHandler;
 
-typedef struct _LingotAudioSystemProperties LingotAudioSystemProperties;
-
-struct _LingotAudioSystemProperties {
+typedef struct {
 
 	int forced_sample_rate; // tells whether the sample rate can be changed
 
 	int n_sample_rates; // number of available sample rates
-	int* sample_rates; // sample rates
+	int sample_rates [5]; // sample rates
 
 	int n_devices; // number of available devices
 	char** devices; // devices
-};
+} LingotAudioSystemProperties;
 
-LingotAudioSystemProperties* lingot_audio_get_audio_system_properties(
+int lingot_audio_get_audio_system_properties(
+		LingotAudioSystemProperties*,
 		audio_system_t audio_system);
+// Return status : 0 for OK, else -1.
+
 void lingot_audio_audio_system_properties_destroy(LingotAudioSystemProperties*);
 
 // creates an audio handler
-LingotAudioHandler
-		*
-		lingot_audio_new(audio_system_t audio_system, char* device,
-				int sample_rate, LingotAudioProcessCallback process_callback,
-				void *process_callback_arg);
+void lingot_audio_new(LingotAudioHandler*,
+		audio_system_t audio_system, const char* device,
+		int sample_rate, LingotAudioProcessCallback process_callback,
+		void *process_callback_arg);
+// In case of failure, audio_system is set to -1 in the LingotAudioHandler struct.
 
 // destroys an audio handler
 void lingot_audio_destroy(LingotAudioHandler*);
