@@ -1,7 +1,9 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2018  Iban Cereijo.
+ * Copyright (C) 2004-2008  Jairo Chapela.
+
  *
  * This file is part of lingot.
  *
@@ -26,19 +28,38 @@
 #include <math.h>
 #include "lingot-defs.h"
 
-// single complex arithmetic  :)
+// single ... complex arithmetic  :)
 
-typedef struct _LingotComplex LingotComplex;
+typedef FLT LingotComplex[2];
 
-struct _LingotComplex
-  {
-    FLT r;
-    FLT i;
-  };
+/**
+ * Addition. All parameters can overlap.
+ */
+void lingot_complex_add(const LingotComplex a, const LingotComplex b, LingotComplex c);
 
-void lingot_complex_add(LingotComplex* a, LingotComplex* b, LingotComplex* c);
-void lingot_complex_sub(LingotComplex* a, LingotComplex* b, LingotComplex* c);
-void lingot_complex_mul(LingotComplex* a, LingotComplex* b, LingotComplex* c);
-void lingot_complex_div(LingotComplex* a, LingotComplex* b, LingotComplex* c);
+/**
+ * Subtraction. All parameters can overlap.
+ */
+void lingot_complex_sub(const LingotComplex a, const LingotComplex b, LingotComplex c);
+
+/**
+ * Multiplication. Parameters cannot overlap.
+ */
+void lingot_complex_mul(const LingotComplex a, const LingotComplex b, LingotComplex c);
+
+/**
+ * Division. Parameters cannot overlap.
+ */
+void lingot_complex_div(const LingotComplex a, const LingotComplex b, LingotComplex c);
+
+/**
+ * Computes a *= b
+ */
+void lingot_complex_mul_by(LingotComplex a, const LingotComplex b);
+
+/**
+ * Computes a /= b
+ */
+void lingot_complex_div_by(LingotComplex a, const LingotComplex b);
 
 #endif
