@@ -1,7 +1,9 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2018  Iban Cereijo.
+ * Copyright (C) 2004-2008  Jairo Chapela.
+
  *
  * This file is part of lingot.
  *
@@ -30,15 +32,12 @@
  * Implements the dynamic behaviour of the gauge with a digital filter.
  */
 
-typedef struct _LingotGauge LingotGauge;
-
-struct _LingotGauge
-  {
-    LingotFilter* filter;
+typedef struct {
+    LingotFilter filter;
     FLT position;
-  };
+  } LingotGauge;;
 
-LingotGauge* lingot_gauge_new(FLT);
+void lingot_gauge_new(LingotGauge*, FLT);
 void lingot_gauge_destroy(LingotGauge*);
 void lingot_gauge_compute(LingotGauge*, FLT);
 
