@@ -1,7 +1,9 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2018  Iban Cereijo.
+ * Copyright (C) 2004-2008  Jairo Chapela.
+
  *
  * This file is part of lingot.
  *
@@ -22,7 +24,6 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <glade/glade.h>
 #include <math.h>
 
 #include "lingot-gui-config-dialog.h"
@@ -34,8 +35,21 @@ enum {
 	COLUMN_NAME = 0, COLUMN_SHIFT = 1, COLUMN_FREQUENCY = 2, NUM_COLUMNS = 3
 };
 
+void lingot_gui_config_dialog_scale_callback_change_deviation(GtkWidget *widget,
+		LingotConfigDialog *dialog) {
+	(void)widget;           //  Unused parameter.
+	gtk_widget_queue_draw(GTK_WIDGET(dialog->scale_treeview));
+}
+
+void lingot_gui_config_dialog_scale_callback_change_octave(GtkWidget *widget,
+		LingotConfigDialog *dialog) {
+	(void)widget;           //  Unused parameter.
+	gtk_widget_queue_draw(GTK_WIDGET(dialog->scale_treeview));
+}
+
 void lingot_gui_config_dialog_scale_tree_add_row_tree(gpointer data,
 		GtkTreeView *treeview) {
+	(void)data;             //  Unused parameter.
 	GtkTreeModel *model;
 	GtkTreeStore *model_store;
 	GtkTreeIter iter1, iter2;
@@ -98,6 +112,7 @@ void lingot_gui_config_dialog_scale_tree_add_row_tree(gpointer data,
 
 void lingot_gui_config_dialog_scale_tree_remove_selected_items(gpointer data,
 		GtkTreeView *treeview) {
+	(void)data;             //  Unused parameter.
 	GtkTreeStore *store;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -142,6 +157,7 @@ void lingot_gui_config_dialog_scale_tree_remove_selected_items(gpointer data,
 void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 		GtkCellRendererText *cell, gchar *path_string, gchar *new_text,
 		gpointer user_data) {
+	(void)path_string;      //  Unused parameter.
 	GtkTreeView *treeview;
 	GtkTreeModel *model;
 	GtkTreeStore *model_store;
@@ -154,7 +170,7 @@ void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 	short int shift_numerator, shift_denominator;
 	gdouble shiftf2, freq2;
 	char* char_pointer;
-	char buff[80];
+	char buff[512];
 	const char* delim = " \t\n";
 	LingotConfigDialog* config_dialog = (LingotConfigDialog*) user_data;
 	int index;
@@ -199,27 +215,27 @@ void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 		return;
 
 	renderer = &cell->parent;
-	guint column_number = GPOINTER_TO_UINT(g_object_get_data(
-					G_OBJECT(renderer), "my_column_num"));
+	guint column_number = GPOINTER_TO_UINT(
+			g_object_get_data( G_OBJECT(renderer), "my_column_num"));
 
 	switch (column_number) {
 
-	case COLUMN_NAME:
+	case COLUMN_NAME: {
 		if (strchr(new_text, ' ') || strchr(new_text, '\t')) {
 			lingot_msg_add_warning(
 					_("Do not use space characters for the note names."));
-		} else if (strchr(new_text, '\n') || strchr(new_text, '{') || strchr(
-				new_text, '}')) {
+		} else if (strchr(new_text, '\n') || strchr(new_text, '{')
+				|| strchr(new_text, '}')) {
 			lingot_msg_add_warning(_("The name contains illegal characters."));
 		} else {
 			char_pointer = strtok(new_text, delim);
-			gtk_tree_store_set(model_store, &iter, COLUMN_NAME, (char_pointer
-					== NULL) ? "?" : new_text, -1);
+			gtk_tree_store_set(model_store, &iter, COLUMN_NAME,
+					(char_pointer == NULL) ? "?" : new_text, -1);
 		}
+	}
 		break;
 
-	case COLUMN_SHIFT:
-
+	case COLUMN_SHIFT: {
 		lingot_config_scale_parse_shift(new_text, &shift_cents,
 				&shift_numerator, &shift_denominator);
 
@@ -231,30 +247,32 @@ void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 			break;
 		}
 
-		if (isnan(shift_cents) || (shift_cents <= 0.0 - 1e-10) || (shift_cents
-				> 1200.0)) {
+		if (isnan(shift_cents) || (shift_cents <= 0.0 - 1e-10)
+				|| (shift_cents > 1200.0)) {
 			lingot_msg_add_warning(
-					_("The shift must be between 0 and 1200 cents, or between 1/1 and 2/1."));
+					_(
+							"The shift must be between 0 and 1200 cents, or between 1/1 and 2/1."));
 			break;
 		}
 
 		gtk_tree_model_get(model, &iter, COLUMN_SHIFT, &stored_shift_char,
 				COLUMN_FREQUENCY, &stored_freq, -1);
 		lingot_config_scale_parse_shift(stored_shift_char, &stored_shift, NULL,
-				NULL);
+		NULL);
 		free(stored_shift_char);
 		lingot_config_scale_format_shift(buff, shift_cents, shift_numerator,
 				shift_denominator);
 		gtk_tree_store_set(model_store, &iter, COLUMN_SHIFT, buff,
-				COLUMN_FREQUENCY, stored_freq * pow(2.0, (shift_cents
-						- stored_shift) / 1200.0), -1);
+				COLUMN_FREQUENCY,
+				stored_freq * pow(2.0, (shift_cents - stored_shift) / 1200.0),
+				-1);
+	}
 		break;
 
-	case COLUMN_FREQUENCY:
-
-		if (!strcmp(new_text, "mid-A")) {
+	case COLUMN_FREQUENCY: {
+		if (!strcmp(new_text, _("mid-A"))) {
 			freq = MID_A_FREQUENCY;
-		} else if (!strcmp(new_text, "mid-C")) {
+		} else if (!strcmp(new_text, _("mid-C"))) {
 			freq = MID_C_FREQUENCY;
 		} else {
 			sscanf(new_text, "%lg", &freq);
@@ -266,8 +284,11 @@ void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 		lingot_config_scale_parse_shift(shift_char, &shift_cents, NULL, NULL);
 		free(shift_char);
 
-		freq *= pow(2.0, -gtk_spin_button_get_value_as_float(
-				config_dialog->root_frequency_error) / 1200.0);
+		freq *= pow(2.0,
+				-gtk_spin_button_get_value(config_dialog->root_frequency_error)
+						/ 1200.0
+						- (gtk_combo_box_get_active(
+								GTK_COMBO_BOX(config_dialog->octave)) - 4));
 		base_freq = freq * pow(2.0, -shift_cents / 1200.0);
 
 		gtk_tree_model_get_iter_first(model, &iter2);
@@ -278,13 +299,13 @@ void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 			lingot_config_scale_parse_shift(shift_char, &shiftf2, NULL, NULL);
 			free(shift_char);
 			freq2 = base_freq * pow(2.0, shiftf2 / 1200.0);
-			gtk_tree_store_set(model_store, &iter2, COLUMN_FREQUENCY, (index
-					== ipath) ? freq : freq2, -1);
+			gtk_tree_store_set(model_store, &iter2, COLUMN_FREQUENCY,
+					(index == ipath) ? freq : freq2, -1);
 			index++;
 		} while (gtk_tree_model_iter_next(model, &iter2));
 
 		//gtk_spin_button_set_value(config_dialog->root_frequency_error, 0.0);
-
+	}
 		break;
 	}
 
@@ -293,18 +314,22 @@ void lingot_gui_config_dialog_scale_tree_cell_edited_callback(
 void lingot_gui_config_dialog_scale_tree_frequency_cell_data_function(
 		GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model,
 		GtkTreeIter *iter, gpointer user_data) {
+	(void)col;              //  Unused parameter.
 	gdouble freq;
 	gchar buf[20];
 	LingotConfigDialog* config_dialog = (LingotConfigDialog*) user_data;
 
 	gtk_tree_model_get(model, iter, COLUMN_FREQUENCY, &freq, -1);
-	freq *= pow(2.0, gtk_spin_button_get_value_as_float(
-			config_dialog->root_frequency_error) / 1200.0);
+	freq *= pow(2.0,
+			gtk_spin_button_get_value(config_dialog->root_frequency_error)
+					/ 1200.0
+					+ (gtk_combo_box_get_active(
+							GTK_COMBO_BOX(config_dialog->octave)) - 4));
 
 	if (fabs(freq - MID_A_FREQUENCY) < 1e-3) {
-		g_object_set(renderer, "text", "mid-A", NULL);
+		g_object_set(renderer, "text", _("mid-A"), NULL);
 	} else if (fabs(freq - MID_C_FREQUENCY) < 1e-3) {
-		g_object_set(renderer, "text", "mid-C", NULL);
+		g_object_set(renderer, "text", _("mid-C"), NULL);
 	} else {
 		g_snprintf(buf, sizeof(buf), "%.4f", freq);
 		g_object_set(renderer, "text", buf, NULL);
@@ -324,14 +349,12 @@ void lingot_gui_config_dialog_scale_tree_add_column(
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(column, renderer, FALSE);
 	gtk_tree_view_column_set_attributes(column, renderer, "text", COLUMN_NAME,
-			NULL);
+	NULL);
 	g_object_set(renderer, "editable", TRUE, NULL);
-	g_object_set_data(G_OBJECT(renderer), "my_column_num", GUINT_TO_POINTER(
-			COLUMN_NAME));
-	g_signal_connect(
-			renderer,
-			"edited",
-			(GCallback) lingot_gui_config_dialog_scale_tree_cell_edited_callback,
+	g_object_set_data(G_OBJECT(renderer), "my_column_num",
+			GUINT_TO_POINTER(COLUMN_NAME));
+	g_signal_connect(renderer, "edited",
+			(GCallback ) lingot_gui_config_dialog_scale_tree_cell_edited_callback,
 			config_dialog);
 
 	gtk_tree_view_append_column(treeview, column);
@@ -341,18 +364,16 @@ void lingot_gui_config_dialog_scale_tree_add_column(
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(column, renderer, FALSE);
 	gtk_tree_view_column_set_attributes(column, renderer, "text", COLUMN_SHIFT,
-			NULL);
+	NULL);
 	g_object_set(renderer, "editable", TRUE, NULL);
-	g_object_set_data(G_OBJECT(renderer), "my_column_num", GUINT_TO_POINTER(
-			COLUMN_SHIFT));
+	g_object_set_data(G_OBJECT(renderer), "my_column_num",
+			GUINT_TO_POINTER(COLUMN_SHIFT));
 	//	gtk_tree_view_column_set_cell_data_func(column, renderer,
 	//			lingot_config_dialog_scale_tree_shift_cell_data_function, NULL,
 	//			NULL);
 
-	g_signal_connect(
-			renderer,
-			"edited",
-			(GCallback) lingot_gui_config_dialog_scale_tree_cell_edited_callback,
+	g_signal_connect(renderer, "edited",
+			(GCallback ) lingot_gui_config_dialog_scale_tree_cell_edited_callback,
 			config_dialog);
 
 	gtk_tree_view_append_column(treeview, column);
@@ -364,24 +385,21 @@ void lingot_gui_config_dialog_scale_tree_add_column(
 	gtk_tree_view_column_set_attributes(column, renderer, "text",
 			COLUMN_FREQUENCY, NULL);
 	g_object_set(renderer, "editable", TRUE, NULL);
-	g_object_set_data(G_OBJECT(renderer), "my_column_num", GUINT_TO_POINTER(
-			COLUMN_FREQUENCY));
+	g_object_set_data(G_OBJECT(renderer), "my_column_num",
+			GUINT_TO_POINTER(COLUMN_FREQUENCY));
 	gtk_tree_view_column_set_cell_data_func(column, renderer,
 			lingot_gui_config_dialog_scale_tree_frequency_cell_data_function,
 			config_dialog, NULL);
 
-	g_signal_connect(
-			renderer,
-			"edited",
-			(GCallback) lingot_gui_config_dialog_scale_tree_cell_edited_callback,
+	g_signal_connect(renderer, "edited",
+			(GCallback ) lingot_gui_config_dialog_scale_tree_cell_edited_callback,
 			config_dialog);
 
 	gtk_tree_view_append_column(treeview, column);
 }
 
-int lingot_gui_config_dialog_scale_validate(LingotConfigDialog* dialog,
-		LingotScale* scale) {
-
+int lingot_gui_config_dialog_scale_validate(const LingotConfigDialog* dialog, const LingotScale* scale) {
+	(void)scale;            //  Unused parameter.
 	GtkTreeIter iter, iter2;
 	GtkTreeModel* model = gtk_tree_view_get_model(dialog->scale_treeview);
 
@@ -400,8 +418,7 @@ int lingot_gui_config_dialog_scale_validate(LingotConfigDialog* dialog,
 	int row1 = 0;
 
 	do {
-		gtk_tree_model_get(model, &iter, COLUMN_NAME, &name, COLUMN_SHIFT,
-				&shift_char, -1);
+		gtk_tree_model_get(model, &iter, COLUMN_NAME, &name, COLUMN_SHIFT, &shift_char, -1);
 		lingot_config_scale_parse_shift(shift_char, &shift, NULL, NULL);
 		free(shift_char);
 
@@ -451,8 +468,8 @@ int lingot_gui_config_dialog_scale_validate(LingotConfigDialog* dialog,
 	return 1;
 }
 
-void lingot_gui_config_dialog_scale_apply(LingotConfigDialog* dialog,
-		LingotScale* scale) {
+void lingot_gui_config_dialog_scale_gui_to_data(const LingotConfigDialog* dialog, LingotScale* scale) {
+
 	GtkTreeIter iter;
 	GtkTreeModel* model = gtk_tree_view_get_model(dialog->scale_treeview);
 	gdouble freq, shift;
@@ -471,10 +488,8 @@ void lingot_gui_config_dialog_scale_apply(LingotConfigDialog* dialog,
 	lingot_config_scale_allocate(scale, rows);
 
 	do {
-		gtk_tree_model_get(model, &iter, COLUMN_NAME, &name, COLUMN_SHIFT,
-				&shift_char, -1);
-		lingot_config_scale_parse_shift(shift_char, &shift, &shift_num,
-				&shift_den);
+		gtk_tree_model_get(model, &iter, COLUMN_NAME, &name, COLUMN_SHIFT, &shift_char, -1);
+		lingot_config_scale_parse_shift(shift_char, &shift, &shift_num, &shift_den);
 		free(shift_char);
 
 		scale->note_name[i] = name;
@@ -485,20 +500,19 @@ void lingot_gui_config_dialog_scale_apply(LingotConfigDialog* dialog,
 	} while (gtk_tree_model_iter_next(model, &iter));
 }
 
-void lingot_gui_config_dialog_scale_rewrite(LingotConfigDialog* dialog,
-		LingotScale* scale) {
+void lingot_gui_config_dialog_scale_data_to_gui(LingotConfigDialog* dialog, const LingotScale* scale) {
 	gtk_entry_set_text(dialog->scale_name, scale->name);
 	GtkTreeStore* store = (GtkTreeStore *) gtk_tree_view_get_model(
 			dialog->scale_treeview);
 	gtk_tree_store_clear(store);
 	GtkTreeIter iter2;
-	char buff[80];
+	char buff[512];
 
 	int i;
 	for (i = 0; i < scale->notes; i++) {
 		gtk_tree_store_append(store, &iter2, NULL);
-		FLT freq = scale->base_frequency * pow(2.0, scale->offset_cents[i]
-				/ 1200.0);
+		FLT freq = scale->base_frequency
+				* pow(2.0, scale->offset_cents[i] / 1200.0);
 		lingot_config_scale_format_shift(buff, scale->offset_cents[i],
 				scale->offset_ratios[0][i], scale->offset_ratios[1][i]);
 		gtk_tree_store_set(store, &iter2, COLUMN_NAME, scale->note_name[i],
@@ -508,9 +522,10 @@ void lingot_gui_config_dialog_scale_rewrite(LingotConfigDialog* dialog,
 
 void lingot_gui_config_dialog_import_scl(gpointer data,
 		LingotConfigDialog* config_dialog) {
+	(void)data;             //  Unused parameter.
 	GtkWidget * dialog = gtk_file_chooser_dialog_new(_("Open Scale File"),
 			GTK_WINDOW(config_dialog->win), GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN,
+			"_Cancel", GTK_RESPONSE_CANCEL, "_Open",
 			GTK_RESPONSE_ACCEPT, NULL);
 	GtkFileFilter *filefilter;
 	filefilter = gtk_file_filter_new();
@@ -528,21 +543,26 @@ void lingot_gui_config_dialog_import_scl(gpointer data,
 	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 		char *filename;
 		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-		if (filechooser_last_folder != NULL)
+		if (filechooser_last_folder != NULL) {
 			free(filechooser_last_folder);
-		filechooser_last_folder = strdup(gtk_file_chooser_get_current_folder(
-				GTK_FILE_CHOOSER(dialog)));
-		// TODO
-		LingotScale* scale = lingot_config_scale_new();
-		if (!lingot_config_scale_load_scl(scale, filename)) {
-			lingot_msg_add_error(_(
-					"The scale cannot be imported: file format error"));
-			lingot_config_scale_destroy(scale);
-			free(scale);
-		} else {
-			lingot_gui_config_dialog_scale_rewrite(config_dialog, scale);
+			filechooser_last_folder = NULL;
 		}
 
+		if (gtk_file_chooser_get_current_folder(
+				GTK_FILE_CHOOSER(dialog)) != NULL) {
+			filechooser_last_folder = strdup(
+					gtk_file_chooser_get_current_folder(
+							GTK_FILE_CHOOSER(dialog)));
+		}
+
+		// TODO
+		LingotScale scale;
+                lingot_config_scale_new(&scale);
+		if (lingot_config_scale_load_scl(&scale, filename)) {
+			lingot_gui_config_dialog_scale_data_to_gui(config_dialog, &scale);
+		}
+
+		lingot_config_scale_destroy(&scale);
 		g_free(filename);
 	}
 	gtk_widget_destroy(dialog);
@@ -551,15 +571,16 @@ void lingot_gui_config_dialog_import_scl(gpointer data,
 
 gint lingot_gui_config_dialog_scale_key_press_cb(GtkWidget *widget,
 		GdkEventKey *kevent, gpointer data) {
+	(void)widget;           //  Unused parameter.
 
 	LingotConfigDialog* dialog = (LingotConfigDialog*) data;
 	if (kevent->type == GDK_KEY_PRESS) {
 		if (kevent->keyval == 0xffff) {
-			g_signal_emit_by_name(G_OBJECT(dialog->button_scale_del),
-					"clicked", NULL);
+			g_signal_emit_by_name(G_OBJECT(dialog->button_scale_del), "clicked",
+			NULL);
 		} else if (kevent->keyval == 0xff63) {
-			g_signal_emit_by_name(G_OBJECT(dialog->button_scale_add),
-					"clicked", NULL);
+			g_signal_emit_by_name(G_OBJECT(dialog->button_scale_add), "clicked",
+			NULL);
 		}
 	}
 
@@ -568,7 +589,8 @@ gint lingot_gui_config_dialog_scale_key_press_cb(GtkWidget *widget,
 
 gint lingot_gui_config_dialog_scale_tree_view_column_get_index(
 		GtkTreeViewColumn *column) {
-	GtkTreeView *tree = GTK_TREE_VIEW(column->tree_view);
+	GtkTreeView *tree = GTK_TREE_VIEW(
+			gtk_tree_view_column_get_tree_view(column));
 	GList *cols = gtk_tree_view_get_columns(tree);
 	int counter = 0;
 
@@ -588,47 +610,54 @@ gint lingot_gui_config_dialog_scale_tree_view_column_get_index(
 gboolean lingot_gui_config_dialog_scale_table_query_tooltip(GtkWidget *widget,
 		gint x, gint y, gboolean keyboard_mode, GtkTooltip *tooltip,
 		gpointer user_data) {
+	(void)keyboard_mode;    //  Unused parameter.
+	(void)user_data;        //  Unused parameter.
+
 	GtkTreePath* path;
 	GtkTreeViewColumn* col;
 	gint cx, cy;
 
-	gtk_tree_view_get_path_at_pos((GtkTreeView*) widget, x, y, &path, &col,
-			&cx, &cy);
+	gtk_tree_view_get_path_at_pos((GtkTreeView*) widget, x, y, &path, &col, &cx,
+			&cy);
 
 	gint column_index =
 			lingot_gui_config_dialog_scale_tree_view_column_get_index(col);
 
 	switch (column_index) {
 	case COLUMN_NAME:
-		gtk_tooltip_set_text(
-				tooltip,
-				_("Note identifier, free text that will be displayed in the main window when tuning close to the given note. Don't use space characters here."));
+		gtk_tooltip_set_text(tooltip,
+				_(
+						"Note identifier, free text that will be displayed in the main window when tuning close to the given note. Don't use space characters here."));
 		break;
 	case COLUMN_SHIFT:
-		gtk_tooltip_set_text(
-				tooltip,
-				_("Shift. You can define it as a deviation in cents from the reference note (the first one), or as a frequency ratio, like '3/2' or '5/4'. All the values must be between 0 and 1200 cents, or between 1/1 and 2/1 (i.e., all the notes must be in the same octave), and they must be well ordered."));
+		gtk_tooltip_set_text(tooltip,
+				_(
+						"Shift. You can define it as a deviation in cents from the reference note (the first one), or as a frequency ratio, like '3/2' or '5/4'. All the values must be between 0 and 1200 cents, or between 1/1 and 2/1 (i.e., all the notes must be in the same octave), and they must be well ordered."));
 		break;
-	case COLUMN_FREQUENCY:
-		gtk_tooltip_set_text(
-				tooltip,
-				_("Frequency. You can enter here the absolute frequency for a given note as a reference, and all the other frequencies will shift according to the deviations specified in the 'Shift' column. You can use an absolute numeric value or the keywords 'mid-C' (261.625565 Hz) and 'mid-A' (440 Hz)."));
+	case COLUMN_FREQUENCY: {
+		char buff[600];
+		snprintf(buff, sizeof(buff),
+				_(
+						"Frequency. You can enter here the absolute frequency for a given note as a reference, and all the other frequencies will shift according to the deviations specified in the 'Shift' column. You can either use an absolute numeric value or the keywords '%s' (261.625565 Hz) and '%s' (440 Hz). Those keywords are normally reserved for the 4th octave (try to assign frequencies only to the 4th octave)."),
+				_("mid-C"), _("mid-A"));
+		gtk_tooltip_set_text(tooltip, buff);
+	}
 		break;
 	}
 
 	return TRUE;
 }
 
-void lingot_gui_config_dialog_scale_show(LingotConfigDialog* dialog,
-		GladeXML* _gladeXML) {
+void lingot_gui_config_dialog_scale_show(LingotConfigDialog* dialog, GtkBuilder* builder) {
 
 	dialog->scale_name = GTK_ENTRY(
-			glade_xml_get_widget(_gladeXML, "scale_name"));
-	GtkWidget* scroll = glade_xml_get_widget(_gladeXML, "scrolledwindow1");
+			gtk_builder_get_object(builder, "scale_name"));
+	GtkWidget* scroll = GTK_WIDGET(
+			gtk_builder_get_object(builder, "scrolledwindow1"));
 
 	/* crea el modelo del arbol */
 	GtkTreeStore *model_store = gtk_tree_store_new(3, G_TYPE_STRING,
-			G_TYPE_STRING, G_TYPE_DOUBLE);
+	G_TYPE_STRING, G_TYPE_DOUBLE);
 	GtkTreeModel* model = GTK_TREE_MODEL(model_store);
 
 	/* crea un nuevo widget gtktreeview */
@@ -639,33 +668,35 @@ void lingot_gui_config_dialog_scale_show(LingotConfigDialog* dialog,
 
 	/* asocia el modelo al gtkteeview */
 	gtk_tree_view_set_model(dialog->scale_treeview, model);
-	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(
-			dialog->scale_treeview), GTK_SELECTION_MULTIPLE);
+	gtk_tree_selection_set_mode(
+			gtk_tree_view_get_selection(dialog->scale_treeview),
+			GTK_SELECTION_MULTIPLE);
 
 	g_object_unref(G_OBJECT(model));
-	gtk_container_add(GTK_CONTAINER(scroll), GTK_WIDGET(dialog->scale_treeview));
+	gtk_container_add(GTK_CONTAINER(scroll),
+			GTK_WIDGET(dialog->scale_treeview));
 
-	dialog->button_scale_del = GTK_BUTTON(glade_xml_get_widget(_gladeXML,
-					"button_scale_del"));
-	dialog->button_scale_add = GTK_BUTTON(glade_xml_get_widget(_gladeXML,
-					"button_scale_add"));
-	GtkButton* button_import = GTK_BUTTON(glade_xml_get_widget(_gladeXML,
-					"button_scale_import"));
+	dialog->button_scale_del = GTK_BUTTON(
+			gtk_builder_get_object(builder, "button_scale_del"));
+	dialog->button_scale_add = GTK_BUTTON(
+			gtk_builder_get_object(builder, "button_scale_add"));
+	GtkButton* button_import = GTK_BUTTON(
+			gtk_builder_get_object(builder, "button_scale_import"));
 
 	g_signal_connect(G_OBJECT(dialog->scale_treeview), "key_press_event",
 			G_CALLBACK(lingot_gui_config_dialog_scale_key_press_cb), dialog);
 
-	g_signal_connect(G_OBJECT(dialog->button_scale_add), "clicked", G_CALLBACK(
-					lingot_gui_config_dialog_scale_tree_add_row_tree),
+	g_signal_connect(G_OBJECT(dialog->button_scale_add), "clicked",
+			G_CALLBACK( lingot_gui_config_dialog_scale_tree_add_row_tree),
 			dialog->scale_treeview);
-	g_signal_connect(G_OBJECT(dialog->button_scale_del), "clicked", G_CALLBACK(
-					lingot_gui_config_dialog_scale_tree_remove_selected_items),
+	g_signal_connect(G_OBJECT(dialog->button_scale_del), "clicked",
+			G_CALLBACK( lingot_gui_config_dialog_scale_tree_remove_selected_items),
 			dialog->scale_treeview);
-	g_signal_connect(G_OBJECT(button_import), "clicked", G_CALLBACK(
-					lingot_gui_config_dialog_import_scl), dialog);
+	g_signal_connect(G_OBJECT(button_import), "clicked",
+			G_CALLBACK( lingot_gui_config_dialog_import_scl), dialog);
 
 	gtk_widget_set_has_tooltip(GTK_WIDGET(dialog->scale_treeview), TRUE);
 	g_signal_connect(G_OBJECT(dialog->scale_treeview), "query-tooltip",
-			(GCallback) lingot_gui_config_dialog_scale_table_query_tooltip,
+			(GCallback ) lingot_gui_config_dialog_scale_table_query_tooltip,
 			NULL);
 }
